===============================
boiseopensourcedemo
===============================

.. image:: https://badge.fury.io/py/boiseopensourcedemo.png
    :target: http://badge.fury.io/py/boiseopensourcedemo

.. image:: https://travis-ci.org/robustican/boiseopensourcedemo.png?branch=master
        :target: https://travis-ci.org/robustican/boiseopensourcedemo

.. image:: https://pypip.in/d/boiseopensourcedemo/badge.png
        :target: https://pypi.python.org/pypi/boiseopensourcedemo


Boise Open Source Demo

* Free software: BSD license
* Documentation: https://boiseopensourcedemo.readthedocs.org.

Features
--------

* TODO